@@ -1,10 +1,14 @@
 from typing import Union, Tuple, List
 import os
-import imageio
 from glob import glob
 import numpy as np
 import pandas as pd
 
+# for python 3.6 compability
+try:
+    from imageio.v3 import imread
+except ImportError:
+    from imageio import imread
 
 PATH = os.path.abspath(os.path.dirname(__file__))
 
@@ -43,7 +47,8 @@ def field(fname: str, band: Union[int, str] = 0) -> np.ndarray:
         fname += '.png'
 
     # read image
-    img = imageio.imread(os.path.join(PATH, 'rf', fname))
+    # TODO: with imageio v3 this can be switched to imageio.imread - the result should be the same here
+    img = imread(os.path.join(PATH, 'rf', fname))
 
     # switch band
     if isinstance(band, int):
@@ -124,3 +129,38 @@ def read_sample_file(fname) -> pd.DataFrame:
     # build the path
     path = os.path.join(PATH, 'samples', fname)
     return pd.read_csv(path)
+
+
+def sample_to_df(coordinates: np.ndarray, values: np.ndarray) -> pd.DataFrame:
+    """
+    Turn the coordinates and values array into a pandas DataFrame.
+    The columns will be called x[,y[,z]],v
+
+    Parameters
+    ----------
+    coordinates : numpy.ndarray
+        Coordinate array of shape ``(N, 1), (N, 2)`` or ``(N, 3)``.
+    values : numpy.ndarray
+        1D array of the values at the coordinates
+
+    Returns
+    -------
+    df : pandas.DataFrame
+        The data as a pandas DataFrame
+
+    """
+    # check that the array sizes match
+    if len(coordinates) != len(values):
+        raise AttributeError('coordinates and values must have the same length')
+
+    # check dimensions
+    col_names = ['x']
+    if coordinates.ndim >= 2:
+        col_names.append('y')
+    if coordinates.ndim == 3:
+        col_names.append('z')
+
+    # build the dataframe
+    df = pd.DataFrame(coordinates, columns=col_names)
+    df['v'] = values
+    return df
