@@ -10,7 +10,7 @@ def stvariogram(func):
         if st.ndim == 2:
             new_args = args[1:]
             mapping = map(lambda lags: func(lags, *new_args, **kwargs), st)
-            return np.fromiter(mapping, dtype=np.float)
+            return np.fromiter(mapping, dtype=float)
         else:
             return func(*args, **kwargs)
     return wrapper
@@ -18,7 +18,7 @@ def stvariogram(func):
 
 @stvariogram
 def sum(lags, Vx, Vt):
-    """Sum space-time model
+    r"""Sum space-time model
 
     Separable space-time variogram model. This is the most basic model as the
     two marginal models of the space and time axis are simply summed up for
@@ -78,7 +78,7 @@ def sum(lags, Vx, Vt):
 
 @stvariogram
 def product(lags, Vx, Vt, Cx, Ct):
-    """Product model
+    r"""Product model
 
     Separable space-time variogram model. This model is based on the product
     of the marginal space and time models.
@@ -130,7 +130,7 @@ def product(lags, Vx, Vt, Cx, Ct):
 
 @stvariogram
 def product_sum(lags, Vx, Vt, k1, k2, k3, Cx, Ct):
-    """Product-Sum space-time model
+    r"""Product-Sum space-time model
 
     Separable space-time variogram model, based on a combination of 'sum' and
     'product' models. Both base models are based on separated marginal
